@@ -3,7 +3,7 @@ BEGIN {
   $Bot::BasicBot::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $Bot::BasicBot::VERSION = '0.88';
+  $Bot::BasicBot::VERSION = '0.89';
 }
 
 use strict;
@@ -158,7 +158,7 @@ sub forkit {
 
     #install a new handler in the POE kernel pointing to
     # $self->{$args{handler}}
-    $poe_kernel->state($args->{handler}, $self);
+    $poe_kernel->state( $args->{handler}, $args->{callback} || $self  );
 
     my $run;
     if (ref($args->{run}) =~ /^CODE/) {
@@ -397,6 +397,18 @@ sub ssl {
     return $self->{ssl} || 0;
 }
 
+sub localaddr {
+    my $self = shift;
+    $self->{localaddr} = shift if @_;
+    return $self->{localaddr} || 0;
+}
+
+sub useipv6 {
+    my $self = shift;
+    $self->{useipv6} = shift if @_;
+    return $self->{useipv6} || 0;
+}
+
 sub nick {
     my $self = shift;
     $self->{nick} = shift if @_;
@@ -496,21 +508,23 @@ sub start_state {
     $kernel->post($self->{IRCNAME}, 'register', 'all');
 
     $kernel->post(
-        $self->{IRCNAME},
-        'connect',
-        {
-            Nick     => $self->nick,
-            Server   => $self->server,
-            Port     => $self->port,
-            Password => $self->password,
-            UseSSL   => $self->ssl,
-            Flood    => $self->flood,
-            $self->charset_encode(
-                Nick     => $self->nick,
-                Username => $self->username,
-                Ircname  => $self->name,
-            ),
-        },
+	$self->{IRCNAME},
+	'connect',
+	{
+	    Nick      => $self->nick,
+	    Server    => $self->server,
+	    Port      => $self->port,
+	    Password  => $self->password,
+	    UseSSL    => $self->ssl,
+	    Flood     => $self->flood,
+	    LocalAddr => $self->localaddr,
+            useipv6   => $self->useipv6,
+	    $self->charset_encode(
+		Nick     => $self->nick,
+		Username => $self->username,
+		Ircname  => $self->name,
+	    ),
+	},
     );
 
     return;
@@ -1155,6 +1169,10 @@ events in your C<said> routine, particularly for longer running
 processes like searches, which will block the bot from receiving or
 sending on channel whilst they take place if you don't fork them.
 
+Inside the subroutine called by forkit, you can send output back to the
+channel by printing lines (followd by C<\n>) to STDOUT. This has the same
+effect as calling L<C<< Bot::BasicBot->say >>|say>.
+
 C<forkit> takes the following arguments:
 
 =over 4
@@ -1174,6 +1192,13 @@ Optional. A method name within your current package which we can
 return the routine's data to. Defaults to the built-in method
 C<say_fork_return> (which simply sends data to channel).
 
+=item callback
+
+Optional. A coderef to execute in place of the handler. If used, the value
+of the handler argument is used to name the POE event. This allows using
+closures and/or having multiple simultanious calls to forkit with unique
+handler for each call.
+
 =item body
 
 Optional. Use this to pass on the body of the incoming message that
@@ -1319,6 +1344,16 @@ undef.
 A boolean to indicate whether or not the server we're going to connect to
 is an SSL server.  Defaults to 0.
 
+=head2 C<localaddr>
+
+The local address to use, for multihomed boxes.  Defaults to undef (use whatever
+source IP address the system deigns is appropriate).
+
+=head C<useipv6>
+
+A boolean to indicate whether IPv6 should be used.  Defaults to undef (use
+IPv4).
+
 =head2 C<nick>
 
 The nick we're going to use.  Defaults to five random letters
